@@ -1,13 +1,14 @@
 require 'rubygems'
 require 'stomp'
-require 'logger'
 require 'timeout'
 require 'digest/md5'
 require 'optparse'
 require 'singleton'
 require 'socket'
 require 'erb'
+require 'shellwords'
 require 'mcollective/monkey_patches'
+require 'tempfile'
 
 # == The Marionette Collective
 #
@@ -32,6 +33,7 @@ module MCollective
 
     autoload :Config, "mcollective/config"
     autoload :Log, "mcollective/log"
+    autoload :Logger, "mcollective/logger"
     autoload :Runner, "mcollective/runner"
     autoload :RunnerStats, "mcollective/runnerstats"
     autoload :Agents, "mcollective/agents"
@@ -45,8 +47,15 @@ module MCollective
     autoload :PluginManager, "mcollective/pluginmanager"
     autoload :RPC, "mcollective/rpc"
     autoload :Request, "mcollective/request"
+    autoload :SSL, "mcollective/ssl"
+    autoload :Application, "mcollective/application"
+    autoload :Applications, "mcollective/applications"
+    autoload :Vendor, "mcollective/vendor"
+    autoload :Shell, "mcollective/shell"
 
-    VERSION="1.0.1"
+    MCollective::Vendor.load_vendored
+
+    VERSION="1.2.0"
 
     def self.version
         VERSION
